=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2008-12-02 05:54:11 +0000
+++ bzrlib/builtins.py	2008-12-03 05:31:27 +0000
@@ -4738,6 +4738,8 @@
     ie. out of the way, until a later time when you can bring them back from
     the shelf with the 'unshelve' command.
 
+    If shelve --list is specified, previously-shelved changes are listed.
+
     Shelve is intended to help separate several sets of changes that have
     been inappropriately mingled.  If you just want to get rid of all changes
     and you don't need to restore them later, use revert.  If you want to
@@ -4760,12 +4762,16 @@
         'message',
         RegistryOption('writer', 'Method to use for writing diffs.',
                        bzrlib.option.diff_writer_registry,
-                       value_switches=True, enum_switch=False)
+                       value_switches=True, enum_switch=False),
+
+        Option('list', help='list shelved changes.'),
     ]
     _see_also = ['unshelve', 'ls-shelf']
 
     def run(self, revision=None, all=False, file_list=None, message=None,
-            writer=None):
+            writer=None, list=False):
+        if list:
+            return self.run_for_list()
         from bzrlib.shelf_ui import Shelver
         if writer is None:
             writer = bzrlib.option.diff_writer_registry.get()
@@ -4775,6 +4781,24 @@
         except errors.UserAbort:
             return 0
 
+    def run_for_list(self):
+        tree = WorkingTree.open('.')
+        tree.lock_read()
+        try:
+            manager = tree.get_shelf_manager()
+            shelves = manager.active_shelves()
+            if len(shelves) == 0:
+                note('No shelved changes.')
+                return 0
+            for shelf_id in reversed(shelves):
+                message = manager.get_metadata(shelf_id).get('message')
+                if message is None:
+                    message = '<no message>'
+                self.outf.write('%3d: %s\n' % (shelf_id, message))
+            return 1
+        finally:
+            tree.unlock()
+
 
 class cmd_unshelve(Command):
     """Restore shelved changes.
@@ -4801,30 +4825,6 @@
         Unshelver.from_args(shelf_id, action).run()
 
 
-class cmd_ls_shelf(Command):
-    """List shelved changes."""
-
-    _see_also = ['shelve', 'unshelve']
-
-    def run(self):
-        tree = WorkingTree.open('.')
-        tree.lock_read()
-        try:
-            manager = tree.get_shelf_manager()
-            shelves = manager.active_shelves()
-            if len(shelves) == 0:
-                note('No shelved changes.')
-                return 0
-            for shelf_id in reversed(shelves):
-                message = manager.get_metadata(shelf_id).get('message')
-                if message is None:
-                    message = '<no message>'
-                self.outf.write('%3d: %s\n' % (shelf_id, message))
-            return 1
-        finally:
-            tree.unlock()
-
-
 def _create_prefix(cur_transport):
     needed = [cur_transport]
     # Recurse upwards until we can create a directory successfully

=== modified file 'bzrlib/tests/blackbox/__init__.py'
--- bzrlib/tests/blackbox/__init__.py	2008-12-02 05:35:51 +0000
+++ bzrlib/tests/blackbox/__init__.py	2008-12-03 05:31:27 +0000
@@ -78,7 +78,6 @@
                      'bzrlib.tests.blackbox.test_log',
                      'bzrlib.tests.blackbox.test_logformats',
                      'bzrlib.tests.blackbox.test_ls',
-                     'bzrlib.tests.blackbox.test_ls_shelf',
                      'bzrlib.tests.blackbox.test_lsprof',
                      'bzrlib.tests.blackbox.test_merge',
                      'bzrlib.tests.blackbox.test_merge_directive',
@@ -104,6 +103,7 @@
                      'bzrlib.tests.blackbox.test_send',
                      'bzrlib.tests.blackbox.test_serve',
                      'bzrlib.tests.blackbox.test_shared_repository',
+                     'bzrlib.tests.blackbox.test_shelve',
                      'bzrlib.tests.blackbox.test_sign_my_commits',
                      'bzrlib.tests.blackbox.test_split',
                      'bzrlib.tests.blackbox.test_status',

=== renamed file 'bzrlib/tests/blackbox/test_ls_shelf.py' => 'bzrlib/tests/blackbox/test_shelve.py'
--- bzrlib/tests/blackbox/test_ls_shelf.py	2008-12-02 05:35:51 +0000
+++ bzrlib/tests/blackbox/test_shelve.py	2008-12-03 05:31:27 +0000
@@ -17,18 +17,18 @@
 from bzrlib import shelf
 from bzrlib.tests import TestCaseWithTransport
 
-class TestLSShelf(TestCaseWithTransport):
+class TestShelveList(TestCaseWithTransport):
 
     def test_no_shelved_changes(self):
         tree = self.make_branch_and_tree('.')
-        err = self.run_bzr('ls-shelf')[1]
+        err = self.run_bzr('shelve --list')[1]
         self.assertEqual('No shelved changes.\n', err)
 
     def test_shelve_one(self):
         tree = self.make_branch_and_tree('.')
         creator = shelf.ShelfCreator(tree, tree.basis_tree(), [])
         shelf_id = tree.get_shelf_manager().shelve_changes(creator, 'Foo')
-        out, err = self.run_bzr('ls-shelf', retcode=1)
+        out, err = self.run_bzr('shelve --list', retcode=1)
         self.assertEqual('', err)
         self.assertEqual('  1: Foo\n', out)
 
@@ -36,7 +36,7 @@
         tree = self.make_branch_and_tree('.')
         creator = shelf.ShelfCreator(tree, tree.basis_tree(), [])
         shelf_id = tree.get_shelf_manager().shelve_changes(creator)
-        out, err = self.run_bzr('ls-shelf', retcode=1)
+        out, err = self.run_bzr('shelve --list', retcode=1)
         self.assertEqual('', err)
         self.assertEqual('  1: <no message>\n', out)
 
@@ -46,6 +46,6 @@
         tree.get_shelf_manager().shelve_changes(creator, 'Foo')
         creator = shelf.ShelfCreator(tree, tree.basis_tree(), [])
         tree.get_shelf_manager().shelve_changes(creator, 'Bar')
-        out, err = self.run_bzr('ls-shelf', retcode=1)
+        out, err = self.run_bzr('shelve --list', retcode=1)
         self.assertEqual('', err)
         self.assertEqual('  2: Bar\n  1: Foo\n', out)

